@@ -11,7 +11,8 @@ import re
 from lxml import objectify
 
 XML_API = "http://www.zdf.de/ZDFmediathek/xmlservice/web/beitragsDetails?id=%i"
-CHUNK_SIZE = 1024*1024*2 # 2 MB
+# CHUNK_SIZE = 1024*1024*2 # 2 MB
+CHUNK_SIZE = 1024*256 # 256 KB
 
 def video_key(video):
     return (
@@ -27,6 +28,9 @@ def get_id(url):
 
     return int(re.search(r"beitrag/video/([0-9]+)/", url).group(1))
 
+def format_mb(bytes):
+    return "%.2f" % (bytes/(1024*1024))
+
 def main():
     if len(sys.argv) == 1:
         print("Need video ID/URL")
@@ -65,17 +69,19 @@ def main():
         print("  from %s" % v.url.text)
 
         size = 0
+        target_size = int(video.info()["Content-Length"].strip())
+
         with open(basename, "wb") as f:
             data = video.read(CHUNK_SIZE)
             while data:
                 size += len(data)
                 f.write(data)
                 data = video.read(CHUNK_SIZE)
-                sys.stdout.write(".")
+                
+                sys.stdout.write(" "*40 + "\r")
+                sys.stdout.write("  %s/%s MB – %0.2f %%\r" % (format_mb(size), format_mb(target_size), round((float(size) / target_size)*100, 2)))
                 sys.stdout.flush()
 
-        print("\nFinished (%.2f MB)." % (size/(1024*1024)))
-
         break
 
     return 0
